yt.visualization.profile_plotter.PhasePlot.set_xlim — The yt Project 3.2-dev documentation

# yt.visualization.profile_plotter.PhasePlot.set_xlim

`PhasePlot.` `set_xlim`(*args, **kwargs)

  Sets the limits of the x bin field

  Parameters: | xmin : float or None The new x minimum. Defaults to None, which leaves the xmin unchanged. xmax : float or None The new x maximum. Defaults to None, which leaves the xmax unchanged.

  Examples

      >>> import yt
      >>> ds = yt.load('IsolatedGalaxy/galaxy0030/galaxy0030')
      >>> pp = yt.PhasePlot(ds.all_data(), 'density', 'temperature', 'cell_mass')
      >>> pp.set_xlim(1e-29, 1e-24)
      >>> pp.save()